@@ -1,12 +1,10 @@
 /*
  * main.c - SiriDB.
  *
- * author       : Jeroen van der Heijden
- * email        : jeroen@transceptor.technology
- * copyright    : 2016, Transceptor Technology
- *
- * changes
- *  - initial version, 08-03-2016
+ * author/maintainer : Jeroen van der Heijden <jeroen@transceptor.technology>
+ * contributors      : https://github.com/SiriDB/siridb-server/contributors
+ * home page         : https://siridb.net
+ * copyright         : 2018, Transceptor Technology
  *
  */
 #include <locale.h>
@@ -21,17 +19,11 @@
 #include <stdlib.h>
 #include <time.h>
 
-#if DEBUG
-#include <test/test.h>
-#endif
 
 int main(int argc, char * argv[])
 {
-    /*
-     * set local to LC_ALL
-     * more info at: http://www.cprogramming.com/tutorial/unicode.html
-     */
-    setlocale(LC_ALL, "");
+    /* set local to LC_ALL */
+    (void) setlocale(LC_ALL, "");
 
     /* initialize random */
     srand(time(NULL));
@@ -52,24 +44,14 @@ int main(int argc, char * argv[])
     /* initialize points dictionary */
     siridb_points_init();
 
-#if DEBUG
-    int rc;
-    /* run tests when we are in debug mode */
-    rc = run_tests();
-    if (rc)
+    /* start server */
+    log_info("Starting SiriDB Server (version: %s)", SIRIDB_VERSION);
+
+    /* initialize SiriDB mutex (used for the siridb_list) */
+    if (uv_mutex_init(&siri.siridb_mutex))
     {
         exit(1);
     }
-    log_warning("Starting SiriDB Server (%s-DEBUG-RELEASE-%s)",
-            SIRIDB_VERSION,
-            SIRIDB_BUILD_DATE);
-#else
-
-    /* start server */
-    log_info("Starting SiriDB Server (version: %s)", SIRIDB_VERSION);
-#endif
-    /* initialize SiriDB mutex (used for the siridb_list) */
-    uv_mutex_init(&siri.siridb_mutex);
 
     /* read siridb main application configuration */
     siri_cfg_init(&siri);
