@@ -1,13 +1,5 @@
 /*
  * cexpr.c - Conditional expressions.
- *
- * author       : Jeroen van der Heijden
- * email        : jeroen@transceptor.technology
- * copyright    : 2016, Transceptor Technology
- *
- * changes
- *  - initial version, 13-06-2016
- *
  */
 #include <cexpr/cexpr.h>
 #include <assert.h>
@@ -18,7 +10,7 @@
 #include <siri/db/series.h>
 #include <siri/db/shard.h>
 #include <siri/db/access.h>
-#include <strextra/strextra.h>
+#include <xstr/xstr.h>
 
 #define VIA_NULL 0
 #define VIA_CEXPR 1
@@ -96,9 +88,7 @@ cexpr_t * cexpr_from_node(cleri_node_t * node)
     {
         /* successful */
         cexpr = CEXPR_close_curly(&list);
-#if DEBUG
         assert (list.len == 0 && condition == NULL);
-#endif
     }
     else if (condition != NULL)
     {
@@ -179,10 +169,7 @@ int cexpr_str_cmp(
         const char * b)
 {
     /* both a and b MUST be terminated strings */
-
-#if DEBUG
     assert (a != NULL && b != NULL);
-#endif
 
     switch (operator)
     {
@@ -218,9 +205,8 @@ int cexpr_bool_cmp(
         const int64_t a,
         const int64_t b)
 {
-#if DEBUG
     assert ((a == 0 || a == 1) && (b == 0 || b == 1));
-#endif
+
     switch (operator)
     {
     case CEXPR_EQ:
@@ -243,10 +229,8 @@ int cexpr_run(cexpr_t * cexpr, cexpr_cb_t cb, void * obj)
     switch (cexpr->operator)
     {
     case CEXPR_AND:
-#if DEBUG
         /* tp_a cannot be VIA_NULL, but tp_b can */
         assert (cexpr->tp_a != VIA_NULL);
-#endif
         return  ((cexpr->tp_a == VIA_CEXPR) ?
                     cexpr_run(cexpr->via_a.cexpr, cb, obj) :
                     cb(obj, cexpr->via_a.cond)) &&
@@ -254,10 +238,8 @@ int cexpr_run(cexpr_t * cexpr, cexpr_cb_t cb, void * obj)
                     cexpr_run(cexpr->via_b.cexpr, cb, obj) :
                     cb(obj, cexpr->via_b.cond)));
     case CEXPR_OR:
-#if DEBUG
         /* both tp_a and tp_b can NEVER be VIA_NULL */
         assert (cexpr->tp_a != VIA_NULL && cexpr->tp_b != VIA_NULL);
-#endif
         return  ((cexpr->tp_a == VIA_CEXPR) ?
                     cexpr_run(cexpr->via_a.cexpr, cb, obj) :
                     cb(obj, cexpr->via_a.cond)) ||
@@ -327,9 +309,7 @@ cexpr_operator_t cexpr_operator_fn(cleri_node_t * node)
     }
     else
     {
-#if DEBUG
         assert (node->len == 2);
-#endif
         switch (*node->str)
         {
         case '=': return CEXPR_EQ;
@@ -414,7 +394,7 @@ static cexpr_t * CEXPR_walk_node(
                 {
                     return NULL;
                 }
-                strx_extract_string((*condition)->str, node->str, node->len);
+                xstr_extract_string((*condition)->str, node->str, node->len);
                 SET_CONDITION_AND_RETURN
             }
             /* can be a choice between keywords, in that case just wait */
@@ -668,9 +648,7 @@ static void CEXPR_push_condition(cexpr_t * cexpr, cexpr_condition_t * cond)
     }
     else
     {
-#if DEBUG
         assert(cexpr->tp_b == VIA_NULL);
-#endif
         cexpr->tp_b = VIA_COND;
         cexpr->via_b.cond = cond;
     }
@@ -704,9 +682,7 @@ static cexpr_t * CEXPR_open_curly(cexpr_t * cexpr, cexpr_list_t * list)
     }
     else
     {
-#if DEBUG
         assert(cexpr->tp_b == VIA_NULL);
-#endif
         cexpr->tp_b = VIA_CEXPR;
         cexpr->via_b.cexpr = new_cexpr;
     }
@@ -716,9 +692,7 @@ static cexpr_t * CEXPR_open_curly(cexpr_t * cexpr, cexpr_list_t * list)
 
 static cexpr_t * CEXPR_close_curly(cexpr_list_t * list)
 {
-#if DEBUG
     assert (list->len > 0);
-#endif
     list->len--;
     return list->cexpr[list->len];
 }
