@@ -6,13 +6,6 @@
  * http://stackoverflow.com/questions/63166/how-to-determine-cpu-and-
  *      memory-consumption-from-inside-a-process
  *
- * author       : Jeroen van der Heijden
- * email        : jeroen@transceptor.technology
- * copyright    : 2016, Transceptor Technology
- *
- * changes
- *  - initial version, 18-03-2016
- *
  */
 
 #include <stdlib.h>
@@ -109,7 +102,7 @@ long int procinfo_total_physical_memory(void)
 #endif
 
 #ifdef __APPLE__
-long int procinfo_open_files(const char * path)
+long int procinfo_open_files(const char * path, int include_fd)
 {
     pid_t pid = getpid();
     size_t len = strlen(path);
@@ -147,22 +140,32 @@ long int procinfo_open_files(const char * path)
             if (    res == PROC_PIDFDVNODEPATHINFO_SIZE &&
                     strncmp(path, vnode_info.pvip.vip_path, len) == 0)
             {
+                vnode_info
                 count++;
             }
+            else if (
+                    res == PROC_PIDFDVNODEPATHINFO_SIZE &&
+                    include_fd >= 0 &&
+                    include_fd == fd_info[i].proc_fd)
+            {
+                include_fd = -1;
+                count++;
+            };
+
         }
     }
     free(fd_info);
     return count;
 }
 #else
-long int procinfo_open_files(const char * path)
+long int procinfo_open_files(const char * path, int include_fd)
 {
     long int count = 0;
     DIR * dirp;
     struct dirent * entry;
     size_t len = strlen(path);
-    char buffer[SIRI_PATH_MAX];
-    char buf[SIRI_PATH_MAX];
+    char buffer[XPATH_MAX];
+    char buf[XPATH_MAX];
 
     if ((dirp = opendir("/proc/self/fd")) == NULL)
     {
@@ -173,8 +176,7 @@ long int procinfo_open_files(const char * path)
     {
         if (entry->d_type == DT_REG || entry->d_type == DT_LNK)
         {
-            snprintf(buffer, SIRI_PATH_MAX, "/proc/self/fd/%s", entry->d_name);
-
+            snprintf(buffer, XPATH_MAX, "/proc/self/fd/%s", entry->d_name);
             if (realpath(buffer, buf) == NULL)
             {
                 continue;
@@ -184,6 +186,13 @@ long int procinfo_open_files(const char * path)
             {
                 count++;
             }
+            else if (
+                    include_fd >= 0 &&
+                    include_fd == strtol(entry->d_name, NULL, 10))
+            {
+                include_fd = -1;
+                count++;
+            };
         }
     }
     closedir(dirp);
