@@ -1,16 +1,6 @@
 /*
  * median.c - Calculate median, median high and median low.
- *
- * author       : Jeroen van der Heijden
- * email        : jeroen@transceptor.technology
- * copyright    : 2016, Transceptor Technology
- *
- * changes
- *  - initial version, 16-04-2016
- *
  */
-
-
 #include <siri/db/median.h>
 #include <siri/db/points.h>
 #include <stdbool.h>
@@ -54,9 +44,7 @@ int siridb_median_find_n(
         siridb_points_t * points,
         uint64_t n)
 {
-#if DEBUG
     assert (points->len >= 2);
-#endif
     int rc = 0;
     uint64_t i, npivot, size_l, size_r;
 
@@ -183,9 +171,7 @@ int siridb_median_real(
         siridb_points_t * points,
         double percentage)
 {
-#if DEBUG
     assert (points->len >= 2);
-#endif
     int rc = 0;
     uint64_t i, npivot, size_l, size_r, n;
     bool found_a, found_b;
