@@ -1,13 +1,5 @@
 /*
- * protocol.c - Protocol for SiriDB.
- *
- * author       : Jeroen van der Heijden
- * email        : jeroen@transceptor.technology
- * copyright    : 2016, Transceptor Technology
- *
- * changes
- *  - initial version, 01-08-2016
- *
+ * protocol.c - Protocol definitions for SiriDB.
  */
 #include <siri/net/protocol.h>
 #include <stdio.h>
@@ -22,18 +14,16 @@ const char * sirinet_cproto_client_str(cproto_client_t n)
     case CPROTO_REQ_INSERT: return "CPROTO_REQ_INSERT";
     case CPROTO_REQ_AUTH: return "CPROTO_REQ_AUTH";
     case CPROTO_REQ_PING: return "CPROTO_REQ_PING";
-    case CPROTO_REQ_INFO: return "CPROTO_REQ_INFO";
 
-    /* deprecated, used by the old SiriDB manage tool */
-    case CPROTO_REQ_LOADDB: return "CPROTO_REQ_LOADDB";
+    /* start internal usage */
     case CPROTO_REQ_REGISTER_SERVER: return "CPROTO_REQ_REGISTER_SERVER";
     case CPROTO_REQ_FILE_SERVERS: return "CPROTO_REQ_FILE_SERVERS";
     case CPROTO_REQ_FILE_USERS: return "CPROTO_REQ_FILE_USERS";
     case CPROTO_REQ_FILE_GROUPS: return "CPROTO_REQ_FILE_GROUPS";
     case CPROTO_REQ_FILE_DATABASE: return "CPROTO_REQ_FILE_DATABASE";
-    /* end deprecated */
+    /* end internal usage */
 
-    case CPROTO_REQ_ADMIN: return "CPROTO_REQ_ADMIN";
+    case CPROTO_REQ_SERVICE: return "CPROTO_REQ_SERVICE";
 
     default:
         sprintf(protocol_str, "CPROTO_CLIENT_TYPE_UNKNOWN (%d)", n);
@@ -49,14 +39,11 @@ const char * sirinet_cproto_server_str(cproto_server_t n)
     case CPROTO_RES_INSERT: return "CPROTO_RES_INSERT";
     case CPROTO_RES_AUTH_SUCCESS: return "CPROTO_RES_AUTH_SUCCESS";
     case CPROTO_RES_ACK: return "CPROTO_RES_ACK";
-
-    /* deprecated, used by the old SiriDB manage tool */
-    case CPROTO_RES_INFO: return "CPROTO_RES_INFO";
     case CPROTO_RES_FILE: return "CPROTO_RES_FILE";
-    /* end deprecated */
 
-    case CPROTO_ACK_ADMIN: return "CPROTO_ACK_ADMIN";
-    case CPROTO_ACK_ADMIN_DATA: return "CPROTO_ACK_ADMIN_DATA";
+    case CPROTO_ACK_SERVICE: return "CPROTO_ACK_SERVICE";
+    case CPROTO_ACK_SERVICE_DATA: return "CPROTO_ACK_SERVICE_DATA";
+
     case CPROTO_ERR_MSG: return "CPROTO_ERR_MSG";
     case CPROTO_ERR_QUERY: return "CPROTO_ERR_QUERY";
     case CPROTO_ERR_INSERT: return "CPROTO_ERR_INSERT";
@@ -67,14 +54,9 @@ const char * sirinet_cproto_server_str(cproto_server_t n)
     case CPROTO_ERR_NOT_AUTHENTICATED: return "CPROTO_ERR_NOT_AUTHENTICATED";
     case CPROTO_ERR_AUTH_CREDENTIALS: return "CPROTO_ERR_AUTH_CREDENTIALS";
     case CPROTO_ERR_AUTH_UNKNOWN_DB: return "CPROTO_ERR_AUTH_UNKNOWN_DB";
-
-    /* deprecated, used by the old SiriDB manage tool */
-    case CPROTO_ERR_LOADING_DB: return "CPROTO_ERR_LOADING_DB";
     case CPROTO_ERR_FILE: return "CPROTO_ERR_FILE";
-    /* end deprecated */
-
-    case CPROTO_ERR_ADMIN: return "CPROTO_ERR_ADMIN";
-    case CPROTO_ERR_ADMIN_INVALID_REQUEST: return "CPROTO_ERR_ADMIN_INVALID_REQUEST";
+    case CPROTO_ERR_SERVICE: return "CPROTO_ERR_SERVICE";
+    case CPROTO_ERR_SERVICE_INVALID_REQUEST: return "CPROTO_ERR_SERVICE_INVALID_REQUEST";
     default:
         sprintf(protocol_str, "CPROTO_SERVER_TYPE_UNKNOWN (%d)", n);
         return protocol_str;
